package hikapro.com.backpack.presenter;

import android.content.Context;
import android.graphics.Bitmap;
import android.os.Bundle;
import android.support.v7.widget.DefaultItemAnimator;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.ViewGroup;
import android.widget.Toast;

import java.lang.ref.WeakReference;

import hikapro.com.backpack.R;
import hikapro.com.backpack.model.Model;
import hikapro.com.backpack.model.entities.Item;
import hikapro.com.backpack.presenter.adapters.ItemDetailAdapter;
import hikapro.com.backpack.view.View;
import hikapro.com.backpack.view.recycler.DetailViewHolder;

/**
 * Created by tariel on 23/04/16.
 */
public class ItemDetailPresenter implements Presenter.ItemDetail {

    private WeakReference<View.ItemDetail>  view;
    private Model.Detail                    model;
    private ItemDetailAdapter               adapter;
    private Item                            item;

    public ItemDetailPresenter() {
        this.adapter        = new ItemDetailAdapter(this);
    }

    // life cycle -->

    @Override
    public void onDestroy(boolean isChangingConfiguration) {
        view = null;
        model.onDestroy(isChangingConfiguration);
        if ( !isChangingConfiguration ) {
            model = null;
        }
    }
    @Override
    public android.view.View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {

        android.view.View view = inflater.inflate(R.layout.fragment_item_detail, container, false);
        LinearLayoutManager llm = new LinearLayoutManager(getActivityContext());
        RecyclerView detailRecycler = (RecyclerView) view.findViewById(R.id.item_detail_recycler);
        detailRecycler.setLayoutManager(llm);
        detailRecycler.setAdapter(adapter);
        detailRecycler.setItemAnimator(new DefaultItemAnimator());
        model.executeQuery();
        return view;
    }
    @Override
    public void onSaveInstanceState(Bundle outState) {

    }
    // life cycle <--

    // process -->

    @Override
    public void notifyDataSetChanged() {
        adapter.notifyDataSetChanged();
    }

    // process <--

    // other impl -->

    @Override
    public void setView(View.ItemDetail view) {
        this.view = new WeakReference<>(view);
        this.item = getView().getItem();
    }
    @Override
    public void setModel(Model.Detail model) {
        this.model = model;
    }

    @Override
    public Model.Detail getModel() {
        return model;
    }

    @Override
    public Item getCurrentItem() {
        return item;
    }

    @Override
    public Context getAppContext() {
        try {
            return getView().getAppContext();
        } catch (NullPointerException e) {
            return null;
        }
    }
    @Override
    public Context getActivityContext() {
        try {
            return getView().getActivityContext();
        } catch (NullPointerException e) {
            return null;
        }
    }
    @Override
    public void showMessage(String message) {
        Toast.makeText(getView().getAppContext(), message, Toast.LENGTH_SHORT).show();
    }

    @Override
    public void displayPicture(Bitmap bitmap) {


    }
    // other impl <--

    private View.ItemDetail getView() throws NullPointerException {
        if ( view != null )
            return view.get();
        else
            throw new NullPointerException("View is unavailable");
    }
}
